@@ -1,13 +1,3 @@
-#!/usr/bin/env ruby
-#
-# Put description here
-#
-# 
-# 
-# 
-#
-
-require 'swig_assert'
 require 'abstract_signature'
 
 include Abstract_signature
@@ -33,7 +23,7 @@ rescue TypeError
   # TypeError: allocator undefined for Abstract_signature::Abstract_foo
 	exceptionRaised = true
 ensure
-  swig_assert( "exceptionRaised", binding)
+  raise RuntimeError unless exceptionRaised
 end
 
 #
@@ -57,6 +47,6 @@ rescue TypeError
   # TypeError: allocator undefined for Abstract_signature::Abstract_bar
 	exceptionRaised = true
 ensure
-  swig_assert( "exceptionRaised", binding)
+  raise RuntimeError unless exceptionRaised
 end
 
