@@ -1,14 +1,3 @@
-#!/usr/bin/env ruby
-#
-# Put description here
-#
-# 
-# 
-# 
-#
-
-require 'swig_assert'
-
 require 'li_std_string'
 
 include Li_std_string
