@@ -7,7 +7,7 @@
  * Support for Wrap by Contract in SWIG.
  * ----------------------------------------------------------------------------- */
 
-char cvsroot_contract_cxx[] = "$Id: contract.cxx 10440 2008-05-11 20:25:12Z wsfulton $";
+char cvsroot_contract_cxx[] = "$Header: /cvsroot/swig/SWIG/Source/Modules/contract.cxx,v 1.17 2006/11/01 23:54:50 wsfulton Exp $";
 
 #include "swigmod.h"
 
@@ -220,14 +220,14 @@ String *Contracts::make_expression(String *s, Node *n) {
 
 /* This function substitutes parameter names for argument names in the
    contract specification.  Note: it is assumed that the wrapper code 
-   uses arg1 for self and arg2..argn for arguments. */
+   uses arg1--argn for arguments. */
 
 void Contracts::substitute_parms(String *s, ParmList *p, int method) {
   int argnum = 1;
   char argname[32];
 
   if (method) {
-    Replaceid(s, "$self", "arg1");
+    Replaceid(s, "self", "arg0");
     argnum++;
   }
   while (p) {
