@@ -7,7 +7,7 @@
  * Various utility functions.
  * ----------------------------------------------------------------------------- */
 
-char cvsroot_utils_cxx[] = "$Id: utils.cxx 10176 2007-11-30 22:34:50Z wsfulton $";
+char cvsroot_utils_cxx[] = "$Header: /cvsroot/swig/SWIG/Source/Modules/utils.cxx,v 1.13 2006/11/01 23:54:52 wsfulton Exp $";
 
 #include <swigmod.h>
 
@@ -46,17 +46,19 @@ int is_member_director(Node *member) {
   return is_member_director(Getattr(member, "parentNode"), member);
 }
 
+
 /* Clean overloaded list.  Removes templates, ignored, and errors */
 
 void clean_overloaded(Node *n) {
   Node *nn = Getattr(n, "sym:overloaded");
   Node *first = 0;
+  int cnt = 0;
   while (nn) {
     String *ntype = nodeType(nn);
     if ((GetFlag(nn, "feature:ignore")) ||
 	(Getattr(nn, "error")) ||
 	(Strcmp(ntype, "template") == 0) ||
-	((Strcmp(ntype, "cdecl") == 0) && is_protected(nn) && !is_member_director(nn))) {
+	((Strcmp(ntype, "cdecl") == 0) && is_protected(nn) && !is_member_director(nn)) || ((Strcmp(ntype, "using") == 0) && !firstChild(nn))) {
       /* Remove from overloaded list */
       Node *ps = Getattr(nn, "sym:previousSibling");
       Node *ns = Getattr(nn, "sym:nextSibling");
@@ -71,6 +73,40 @@ void clean_overloaded(Node *n) {
       Delattr(nn, "sym:overloaded");
       nn = ns;
       continue;
+    } else if ((Strcmp(ntype, "using") == 0)) {
+      /* A possibly dangerous parse tree hack.  We're going to
+         cut the parse tree node out and stick in the resolved
+         using declarations */
+
+      Node *ps = Getattr(nn, "sym:previousSibling");
+      Node *ns = Getattr(nn, "sym:nextSibling");
+      Node *un = firstChild(nn);
+      Node *pn = un;
+
+      if (!first) {
+	first = un;
+      }
+      while (pn) {
+	Node *ppn = Getattr(pn, "sym:nextSibling");
+	Setattr(pn, "sym:overloaded", first);
+	Setattr(pn, "sym:overname", NewStringf("%s_%d", Getattr(nn, "sym:overname"), cnt++));
+	if (ppn)
+	  pn = ppn;
+	else
+	  break;
+      }
+      if (ps) {
+	Setattr(ps, "sym:nextSibling", un);
+	Setattr(un, "sym:previousSibling", ps);
+      }
+      if (ns) {
+	Setattr(ns, "sym:previousSibling", pn);
+	Setattr(pn, "sym:nextSibling", ns);
+      }
+      if (!first) {
+	first = un;
+	Setattr(nn, "sym:overloaded", first);
+      }
     } else {
       if (!first)
 	first = nn;
@@ -79,7 +115,6 @@ void clean_overloaded(Node *n) {
     nn = Getattr(nn, "sym:nextSibling");
   }
   if (!first || (first && !Getattr(first, "sym:nextSibling"))) {
-    if (Getattr(n, "sym:overloaded"))
-      Delattr(n, "sym:overloaded");
+    Delattr(n, "sym:overloaded");
   }
 }
