@@ -9,14 +9,18 @@
  * are provided.
  * ----------------------------------------------------------------------------- */
 
-char cvsroot_include_c[] = "$Id: include.c 10540 2008-06-21 15:23:02Z wsfulton $";
+char cvsroot_include_c[] = "$Header: /cvsroot/swig/SWIG/Source/Swig/include.c,v 1.33 2006/11/01 23:54:53 wsfulton Exp $";
 
 #include "swig.h"
+#include "swigkeys.h"
 
-static List   *directories = 0;	        /* List of include directories */
-static String *lastpath = 0;	        /* Last file that was included */
-static List   *pdirectories = 0;        /* List of pushed directories  */
-static int     dopush = 1;		/* Whether to push directories */
+/* Delimeter used in accessing files and directories */
+
+static List *directories = 0;	/* List of include directories */
+static String *lastpath = 0;	/* Last file that was included */
+static String *swiglib = 0;	/* Location of SWIG library */
+static String *lang_config = 0;	/* Language configuration file */
+static int dopush = 1;		/* Whether to push directories */
 
 /* This functions determine whether to push/pop dirs in the preprocessor */
 void Swig_set_push_dir(int push) {
@@ -27,6 +31,34 @@ int Swig_get_push_dir(void) {
   return dopush;
 }
 
+
+/* This function sets the name of the configuration file */
+
+void Swig_set_config_file(const String_or_char *filename) {
+  lang_config = NewString(filename);
+}
+
+String *Swig_get_config_file() {
+  return lang_config;
+}
+
+
+/* -----------------------------------------------------------------------------
+ * Swig_swiglib_set()
+ * Swig_swiglib_get()
+ *
+ * Set the location of the SWIG library.  This isn't really used, by the
+ * include mechanism, but rather as a query interface for language modules.
+ * ----------------------------------------------------------------------------- */
+
+void Swig_swiglib_set(const String_or_char *sl) {
+  swiglib = NewString(sl);
+}
+
+String *Swig_swiglib_get() {
+  return swiglib;
+}
+
 /* -----------------------------------------------------------------------------
  * Swig_add_directory()
  *
@@ -34,18 +66,24 @@ int Swig_get_push_dir(void) {
  * ----------------------------------------------------------------------------- */
 
 List *Swig_add_directory(const String_or_char *dirname) {
-  String *adirname;
   if (!directories)
     directories = NewList();
   assert(directories);
   if (dirname) {
-    adirname = NewString(dirname);
-    Append(directories,adirname);
-    Delete(adirname);
+    String *sdir = NewString(dirname);
+    Hash *dir = NewHash();
+    assert(dir);
+    SetFlag(dir, k_sysdir);
+    Setattr(dir, k_name, sdir);
+    Append(directories, dir);
+    Delete(dir);
+    Delete(sdir);
   }
   return directories;
 }
 
+
+
 /* -----------------------------------------------------------------------------
  * Swig_push_directory()
  *
@@ -54,16 +92,23 @@ List *Swig_add_directory(const String_or_char *dirname) {
  * ----------------------------------------------------------------------------- */
 
 void Swig_push_directory(const String_or_char *dirname) {
-  String *pdirname;
+  String *tmp = 0;
   if (!Swig_get_push_dir())
     return;
-  if (!pdirectories)
-    pdirectories = NewList();
-  assert(pdirectories);
-  pdirname = NewString(dirname);
-  assert(pdirname);
-  Insert(pdirectories,0,pdirname);
-  Delete(pdirname);
+  if (!directories)
+    directories = NewList();
+  assert(directories);
+  if (!DohIsString(dirname)) {
+    dirname = tmp = NewString(dirname);
+    assert(dirname);
+  }
+  if (dirname) {
+    Hash *dir = NewHash();
+    Setattr(dir, k_name, dirname);
+    Insert(directories, 0, dir);
+    if (tmp)
+      Delete(tmp);
+  }
 }
 
 /* -----------------------------------------------------------------------------
@@ -76,9 +121,9 @@ void Swig_push_directory(const String_or_char *dirname) {
 void Swig_pop_directory() {
   if (!Swig_get_push_dir())
     return;
-  if (!pdirectories)
+  if (!directories)
     return;
-  Delitem(pdirectories, 0);
+  Delitem(directories, 0);
 }
 
 /* -----------------------------------------------------------------------------
@@ -100,45 +145,57 @@ String *Swig_last_file() {
 
 static List *Swig_search_path_any(int syspath) {
   String *filename;
-  List   *slist;
-  int     i, ilen;
+  String *dirname;
+  List *slist, *llist;
+  int i, ilen;
 
+  llist = 0;
   slist = NewList();
   assert(slist);
   filename = NewStringEmpty();
   assert(filename);
 #ifdef MACSWIG
-  Printf(filename, "%s", SWIG_FILE_DELIMITER);
+  Printf(filename, "%s", SWIG_FILE_DELIMETER);
 #else
-  Printf(filename, ".%s", SWIG_FILE_DELIMITER);
+  Printf(filename, ".%s", SWIG_FILE_DELIMETER);
 #endif
-  Append(slist, filename);
-  Delete(filename);
-  
-  /* If there are any pushed directories.  Add them first */
-  if (pdirectories) {
-    ilen = Len(pdirectories);
-    for (i = 0; i < ilen; i++) {
-      filename = NewString(Getitem(pdirectories,i));
-      Append(filename,SWIG_FILE_DELIMITER);
-      Append(slist,filename);
-      Delete(filename);
-    }
+  if (syspath) {
+    llist = NewList();
+    assert(llist);
+    Append(llist, filename);
+  } else {
+    Append(slist, filename);
   }
-  /* Add system directories next */
   ilen = Len(directories);
   for (i = 0; i < ilen; i++) {
-    filename = NewString(Getitem(directories,i));
-    Append(filename,SWIG_FILE_DELIMITER);
-    if (syspath) {
-      /* If doing a system include, put the system directories first */
-      Insert(slist,i,filename);
+    int issimple = 0;
+    dirname = Getitem(directories, i);
+    filename = NewStringEmpty();
+    assert(filename);
+    if (DohIsString(dirname)) {
+      filename = Copy(dirname);
+      issimple = 1;
     } else {
-      /* Otherwise, just put the system directories after the pushed directories (if any) */
-      Append(slist,filename);
+      filename = Copy(Getattr(dirname, k_name));
+    }
+    StringAppend(filename, SWIG_FILE_DELIMETER);
+
+    if (syspath && (issimple || !GetFlag(dirname, k_sysdir))) {
+      Append(llist, filename);
+    } else {
+      Append(slist, filename);
+      /* Insert(slist,0,filename); */
     }
     Delete(filename);
   }
+  if (syspath) {
+    int ilen = Len(llist);
+    for (i = 0; i < ilen; i++) {
+      Append(slist, Getitem(llist, i));
+    }
+    Delete(llist);
+  }
+
   return slist;
 }
 
@@ -212,15 +269,16 @@ String *Swig_read_file(FILE *f) {
 
   assert(str);
   while (fgets(buffer, 4095, f)) {
-    Append(str, buffer);
+    StringAppend(str, buffer);
   }
-  len = Len(str);
+  len = StringLen(str);
   if (len) {
     char *cstr = Char(str);
     if (cstr[len - 1] != '\n') {
-      Append(str, "\n");
+      StringAppend(str, "\n");
     }
   }
+
   return str;
 }
 
@@ -256,6 +314,7 @@ String *Swig_include_sys(const String_or_char *name) {
   return Swig_include_any(name, 1);
 }
 
+
 /* -----------------------------------------------------------------------------
  * Swig_insert_file()
  *
@@ -348,12 +407,11 @@ char *Swig_file_basename(const String_or_char *filename) {
  * ----------------------------------------------------------------------------- */
 char *Swig_file_filename(const String_or_char *filename) {
   static char tmp[1024];
-  const char *delim = SWIG_FILE_DELIMITER;
+  const char *delim = SWIG_FILE_DELIMETER;
   char *c;
 
   strcpy(tmp, Char(filename));
-  c = strrchr(tmp, *delim);
-  if (c)
+  if ((c = strrchr(tmp, *delim)))
     return c + 1;
   else
     return tmp;
@@ -366,7 +424,7 @@ char *Swig_file_filename(const String_or_char *filename) {
  * ----------------------------------------------------------------------------- */
 char *Swig_file_dirname(const String_or_char *filename) {
   static char tmp[1024];
-  const char *delim = SWIG_FILE_DELIMITER;
+  const char *delim = SWIG_FILE_DELIMETER;
   char *c;
   strcpy(tmp, Char(filename));
   if (!strstr(tmp, delim)) {
